# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`useradd`](#useradd): Manage settings regarding users and user creation  author: SIMP Team <simp@simp-project.com>
* [`useradd::etc_profile`](#useradd--etc_profile): This class takes various SIMP security-related settings and applies them to the appropriate /etc/profile.d/simp.* files to enforce them at lo
* [`useradd::libuser_conf`](#useradd--libuser_conf): Sets up /etc/libuser.conf. See libuser.conf(5) for information on the various variables.  author: SIMP Team <simp@simp-project.com>
* [`useradd::login_defs`](#useradd--login_defs): Set up the /etc/login.defs configuration file. All option values are taken directly from the system documentation.  Any parameter that is a l
* [`useradd::nss`](#useradd--nss): Install and configure the NSS configuration file. See nss(5) for more details.  author: SIMP Team <simp@simp-project.com>
* [`useradd::passwd`](#useradd--passwd): Manage the permissions of shadow and passwd related files  author: SIMP Team <simp@simp-project.com>
* [`useradd::sysconfig_init`](#useradd--sysconfig_init): Allow for the configuration of /etc/sysconfig/init  See /usr/share/doc/initscripts-<version>/sysconfig.txt for variable   definitions.  For a
* [`useradd::useradd`](#useradd--useradd): Install and configure the useradd default configuration file. See useradd(8) for more details.  author: SIMP Team <simp@simp-project.com>

### Data types

* [`Useradd::Bootup`](#Useradd--Bootup): Boot mode sysconfig option
* [`Useradd::CryptStyle`](#Useradd--CryptStyle): The  algorithm to use for password encryption when creating new passwords
* [`Useradd::LibuserModule`](#Useradd--LibuserModule): Valid libuser modules

## Classes

### <a name="useradd"></a>`useradd`

Manage settings regarding users and user creation

author: SIMP Team <simp@simp-project.com>

#### Parameters

The following parameters are available in the `useradd` class:

* [`manage_useradd`](#-useradd--manage_useradd)
* [`manage_login_defs`](#-useradd--manage_login_defs)
* [`manage_libuser_conf`](#-useradd--manage_libuser_conf)
* [`manage_etc_profile`](#-useradd--manage_etc_profile)
* [`manage_sysconfig_init`](#-useradd--manage_sysconfig_init)
* [`manage_nss`](#-useradd--manage_nss)
* [`manage_passwd_perms`](#-useradd--manage_passwd_perms)
* [`securetty`](#-useradd--securetty)
* [`shells_default`](#-useradd--shells_default)
* [`shells`](#-useradd--shells)

##### <a name="-useradd--manage_useradd"></a>`manage_useradd`

Data type: `Boolean`

If true, manage `/etc/default/useradd`

Default value: `true`

##### <a name="-useradd--manage_login_defs"></a>`manage_login_defs`

Data type: `Boolean`

If true, manage `/etc/login.defs`

Default value: `true`

##### <a name="-useradd--manage_libuser_conf"></a>`manage_libuser_conf`

Data type: `Boolean`

If true, manage `/etc/libuser.conf`

Default value: `true`

##### <a name="-useradd--manage_etc_profile"></a>`manage_etc_profile`

Data type: `Boolean`

If true, manage `/etc/profile/simp.*`

Default value: `true`

##### <a name="-useradd--manage_sysconfig_init"></a>`manage_sysconfig_init`

Data type: `Boolean`

If true, manage `/etc/sysconfig/init`

Default value: `true`

##### <a name="-useradd--manage_nss"></a>`manage_nss`

Data type: `Boolean`

If true, manage `/etc/default/nss`

Default value: `true`

##### <a name="-useradd--manage_passwd_perms"></a>`manage_passwd_perms`

Data type: `Boolean`

If true, manage the permissions of shadow and passwd related files

Default value: `true`

##### <a name="-useradd--securetty"></a>`securetty`

Data type: `Variant[Boolean,Array[String]]`

List of ttys available to log into
Defaults to ['tty0', 'tty1', 'tty2', 'tty3', 'tty4']

* If set to false, management of /etc/securetty will be disabled
* If the Array is empty(default) or set to true, root will not be able to log into
  any physical console. This does not prevent root login from anywhere
  else.
* If the string 'ANY_SHELL' is found in the Array, then the
  ``/etc/securetty`` file will be removed and root will be able to login
  from anywhere.

Default value: `['tty0', 'tty1', 'tty2', 'tty3', 'tty4']`

##### <a name="-useradd--shells_default"></a>`shells_default`

Data type: `Array[Stdlib::AbsolutePath]`

List of shells that will appear on the system by default

* These have been set to the usual suspects and users should use the
  ``shells`` parameter to add to the list

Default value: `[ '/bin/sh','/bin/bash','/sbin/nologin','/usr/bin/sh','/usr/bin/bash','/usr/sbin/nologin' ]`

##### <a name="-useradd--shells"></a>`shells`

Data type: `Variant[Boolean,Array[Stdlib::AbsolutePath]]`

List of shells available to the user to set as default

* Set to false to disable management
* Will be combined with ``shells_default`` in /etc/shells

Default value: `[]`

### <a name="useradd--etc_profile"></a>`useradd::etc_profile`

This class takes various SIMP security-related settings and
applies them to the appropriate /etc/profile.d/simp.* files to
enforce them at login for all users.

Currently only supports csh and sh files in profile.d.

author: SIMP Team <simp@simp-project.com>

#### Parameters

The following parameters are available in the `useradd::etc_profile` class:

* [`session_timeout`](#-useradd--etc_profile--session_timeout)
* [`umask`](#-useradd--etc_profile--umask)
* [`mesg`](#-useradd--etc_profile--mesg)
* [`user_whitelist`](#-useradd--etc_profile--user_whitelist)
* [`prepend`](#-useradd--etc_profile--prepend)
* [`append`](#-useradd--etc_profile--append)

##### <a name="-useradd--etc_profile--session_timeout"></a>`session_timeout`

Data type: `Integer`

The number of *minutes* that a user may be idle prior to being
logged out. This is a logical extension of the SCAP Security Guide
requirements for Graphical and SSH timeouts and takes the place of
a terminal screen lock since we haven't found one that works in
100% of the authentication scenarios.

Default value: `15`

##### <a name="-useradd--etc_profile--umask"></a>`umask`

Data type: `String`

The umask that will be applied to the user upon login.
Covers CCE-26917-5, CCE-27034-8, and CCE-26669-2

Default value: `'0077'`

##### <a name="-useradd--etc_profile--mesg"></a>`mesg`

Data type: `Boolean`

Boolean
If true, set mesg to allow writes to user terminals using wall,
etc...

Default value: `false`

##### <a name="-useradd--etc_profile--user_whitelist"></a>`user_whitelist`

Data type: `Array`

A list of users that you don't want to be affected by these
settings.

Default value: `[]`

##### <a name="-useradd--etc_profile--prepend"></a>`prepend`

Data type: `Hash`

Content that you want prepended to the settings scripts.
The hash takes the form 'extension' => 'content'.
Content will be written exactly as provided, no custom formatting
will be performed.

Example:
  { 'sh' => 'if [ $UID -eq 0 ]; then echo "foo"; fi ' }
Result:
  = /etc/profile.d/simp.sh =
   if [ $UID -eq 0 ]; then echo "foo"; fi
   <usual content>

Default value: `{}`

##### <a name="-useradd--etc_profile--append"></a>`append`

Data type: `Hash`

Content that you want appended to the settings scripts.
See $prepend for usage.

Default value: `{}`

### <a name="useradd--libuser_conf"></a>`useradd::libuser_conf`

Sets up /etc/libuser.conf.
See libuser.conf(5) for information on the various variables.

author: SIMP Team <simp@simp-project.com>

#### Parameters

The following parameters are available in the `useradd::libuser_conf` class:

* [`defaults_modules`](#-useradd--libuser_conf--defaults_modules)
* [`defaults_create_modules`](#-useradd--libuser_conf--defaults_create_modules)
* [`defaults_crypt_style`](#-useradd--libuser_conf--defaults_crypt_style)
* [`defaults_hash_rounds_min`](#-useradd--libuser_conf--defaults_hash_rounds_min)
* [`defaults_hash_rounds_max`](#-useradd--libuser_conf--defaults_hash_rounds_max)
* [`defaults_mailspooldir`](#-useradd--libuser_conf--defaults_mailspooldir)
* [`defaults_moduledir`](#-useradd--libuser_conf--defaults_moduledir)
* [`defaults_skeleton`](#-useradd--libuser_conf--defaults_skeleton)
* [`import_login_defs`](#-useradd--libuser_conf--import_login_defs)
* [`import_default_useradd`](#-useradd--libuser_conf--import_default_useradd)
* [`userdefaults`](#-useradd--libuser_conf--userdefaults)
* [`groupdefaults`](#-useradd--libuser_conf--groupdefaults)
* [`files_directory`](#-useradd--libuser_conf--files_directory)
* [`files_nonroot`](#-useradd--libuser_conf--files_nonroot)
* [`shadow_directory`](#-useradd--libuser_conf--shadow_directory)
* [`shadow_nonroot`](#-useradd--libuser_conf--shadow_nonroot)
* [`ldap_userbranch`](#-useradd--libuser_conf--ldap_userbranch)
* [`ldap_groupbranch`](#-useradd--libuser_conf--ldap_groupbranch)
* [`ldap_server`](#-useradd--libuser_conf--ldap_server)
* [`ldap_basedn`](#-useradd--libuser_conf--ldap_basedn)
* [`ldap_binddn`](#-useradd--libuser_conf--ldap_binddn)
* [`ldap_user`](#-useradd--libuser_conf--ldap_user)
* [`ldap_password`](#-useradd--libuser_conf--ldap_password)
* [`ldap_authuser`](#-useradd--libuser_conf--ldap_authuser)
* [`ldap_bindtype`](#-useradd--libuser_conf--ldap_bindtype)
* [`sasl_appname`](#-useradd--libuser_conf--sasl_appname)
* [`sasl_domain`](#-useradd--libuser_conf--sasl_domain)

##### <a name="-useradd--libuser_conf--defaults_modules"></a>`defaults_modules`

Data type: `Array[Useradd::LibuserModule]`



Default value: `['files','shadow']`

##### <a name="-useradd--libuser_conf--defaults_create_modules"></a>`defaults_create_modules`

Data type: `Array[Useradd::LibuserModule]`



Default value: `['files','shadow']`

##### <a name="-useradd--libuser_conf--defaults_crypt_style"></a>`defaults_crypt_style`

Data type: `Useradd::CryptStyle`



Default value: `'sha512'`

##### <a name="-useradd--libuser_conf--defaults_hash_rounds_min"></a>`defaults_hash_rounds_min`

Data type: `Optional[Integer[1000,999999999]]`



Default value: `undef`

##### <a name="-useradd--libuser_conf--defaults_hash_rounds_max"></a>`defaults_hash_rounds_max`

Data type: `Optional[Integer[1000,999999999]]`



Default value: `undef`

##### <a name="-useradd--libuser_conf--defaults_mailspooldir"></a>`defaults_mailspooldir`

Data type: `Optional[Stdlib::AbsolutePath]`



Default value: `undef`

##### <a name="-useradd--libuser_conf--defaults_moduledir"></a>`defaults_moduledir`

Data type: `Optional[Stdlib::AbsolutePath]`



Default value: `undef`

##### <a name="-useradd--libuser_conf--defaults_skeleton"></a>`defaults_skeleton`

Data type: `Optional[Stdlib::AbsolutePath]`



Default value: `undef`

##### <a name="-useradd--libuser_conf--import_login_defs"></a>`import_login_defs`

Data type: `Stdlib::AbsolutePath`



Default value: `'/etc/login.defs'`

##### <a name="-useradd--libuser_conf--import_default_useradd"></a>`import_default_useradd`

Data type: `Stdlib::AbsolutePath`



Default value: `'/etc/default/useradd'`

##### <a name="-useradd--libuser_conf--userdefaults"></a>`userdefaults`

Data type: `String`



Default value: `"LU_USERNAME = %n\nLU_GIDNUMBER = %u"`

##### <a name="-useradd--libuser_conf--groupdefaults"></a>`groupdefaults`

Data type: `String`



Default value: `'LU_GROUPNAME = %n'`

##### <a name="-useradd--libuser_conf--files_directory"></a>`files_directory`

Data type: `Optional[Stdlib::AbsolutePath]`



Default value: `undef`

##### <a name="-useradd--libuser_conf--files_nonroot"></a>`files_nonroot`

Data type: `Optional[Boolean]`



Default value: `undef`

##### <a name="-useradd--libuser_conf--shadow_directory"></a>`shadow_directory`

Data type: `Optional[Stdlib::AbsolutePath]`



Default value: `undef`

##### <a name="-useradd--libuser_conf--shadow_nonroot"></a>`shadow_nonroot`

Data type: `Optional[Boolean]`



Default value: `undef`

##### <a name="-useradd--libuser_conf--ldap_userbranch"></a>`ldap_userbranch`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-useradd--libuser_conf--ldap_groupbranch"></a>`ldap_groupbranch`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-useradd--libuser_conf--ldap_server"></a>`ldap_server`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-useradd--libuser_conf--ldap_basedn"></a>`ldap_basedn`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-useradd--libuser_conf--ldap_binddn"></a>`ldap_binddn`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-useradd--libuser_conf--ldap_user"></a>`ldap_user`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-useradd--libuser_conf--ldap_password"></a>`ldap_password`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-useradd--libuser_conf--ldap_authuser"></a>`ldap_authuser`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-useradd--libuser_conf--ldap_bindtype"></a>`ldap_bindtype`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-useradd--libuser_conf--sasl_appname"></a>`sasl_appname`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-useradd--libuser_conf--sasl_domain"></a>`sasl_domain`

Data type: `Optional[String]`



Default value: `undef`

### <a name="useradd--login_defs"></a>`useradd::login_defs`

Set up the /etc/login.defs configuration file.
All option values are taken directly from the system documentation.

Any parameter that is a list will require an array to be passed.

NOTE: pass_min_len and pass_max_len will NOT have any effect on a stock RedHat machine.
    * Max length will only affect 3des encryption, which is not used on modern machines.
    * Min length should be configured using /etc/pam.d/ or /etc/security/pwquality.conf.

author: SIMP Team <simp@simp-project.com>

#### Parameters

The following parameters are available in the `useradd::login_defs` class:

* [`encrypt_method`](#-useradd--login_defs--encrypt_method)
* [`chfn_auth`](#-useradd--login_defs--chfn_auth)
* [`chfn_restrict`](#-useradd--login_defs--chfn_restrict)
* [`chsh_auth`](#-useradd--login_defs--chsh_auth)
* [`console`](#-useradd--login_defs--console)
* [`console_groups`](#-useradd--login_defs--console_groups)
* [`create_home`](#-useradd--login_defs--create_home)
* [`default_home`](#-useradd--login_defs--default_home)
* [`env_hz`](#-useradd--login_defs--env_hz)
* [`env_path`](#-useradd--login_defs--env_path)
* [`env_supath`](#-useradd--login_defs--env_supath)
* [`env_tz`](#-useradd--login_defs--env_tz)
* [`environ_file`](#-useradd--login_defs--environ_file)
* [`erasechar`](#-useradd--login_defs--erasechar)
* [`fail_delay`](#-useradd--login_defs--fail_delay)
* [`faillog_enab`](#-useradd--login_defs--faillog_enab)
* [`fake_shell`](#-useradd--login_defs--fake_shell)
* [`ftmp_file`](#-useradd--login_defs--ftmp_file)
* [`gid_max`](#-useradd--login_defs--gid_max)
* [`gid_min`](#-useradd--login_defs--gid_min)
* [`hushlogin_file`](#-useradd--login_defs--hushlogin_file)
* [`issue_file`](#-useradd--login_defs--issue_file)
* [`killchar`](#-useradd--login_defs--killchar)
* [`lastlog_enab`](#-useradd--login_defs--lastlog_enab)
* [`login_string`](#-useradd--login_defs--login_string)
* [`login_retries`](#-useradd--login_defs--login_retries)
* [`login_timeout`](#-useradd--login_defs--login_timeout)
* [`log_ok_logins`](#-useradd--login_defs--log_ok_logins)
* [`log_unkfail_enab`](#-useradd--login_defs--log_unkfail_enab)
* [`mail_check_enab`](#-useradd--login_defs--mail_check_enab)
* [`mail_dir`](#-useradd--login_defs--mail_dir)
* [`mail_file`](#-useradd--login_defs--mail_file)
* [`max_members_per_group`](#-useradd--login_defs--max_members_per_group)
* [`motd_file`](#-useradd--login_defs--motd_file)
* [`nologins_file`](#-useradd--login_defs--nologins_file)
* [`obscure_checks_enab`](#-useradd--login_defs--obscure_checks_enab)
* [`pass_always_warn`](#-useradd--login_defs--pass_always_warn)
* [`pass_change_tries`](#-useradd--login_defs--pass_change_tries)
* [`pass_max_days`](#-useradd--login_defs--pass_max_days)
* [`pass_min_days`](#-useradd--login_defs--pass_min_days)
* [`pass_warn_age`](#-useradd--login_defs--pass_warn_age)
* [`pass_max_len`](#-useradd--login_defs--pass_max_len)
* [`pass_min_len`](#-useradd--login_defs--pass_min_len)
* [`porttime_checks_enab`](#-useradd--login_defs--porttime_checks_enab)
* [`quotas_enab`](#-useradd--login_defs--quotas_enab)
* [`sha_crypt_min_rounds`](#-useradd--login_defs--sha_crypt_min_rounds)
* [`sha_crypt_max_rounds`](#-useradd--login_defs--sha_crypt_max_rounds)
* [`sulog_file`](#-useradd--login_defs--sulog_file)
* [`su_name`](#-useradd--login_defs--su_name)
* [`su_wheel_only`](#-useradd--login_defs--su_wheel_only)
* [`sys_gid_max`](#-useradd--login_defs--sys_gid_max)
* [`sys_gid_min`](#-useradd--login_defs--sys_gid_min)
* [`sys_uid_max`](#-useradd--login_defs--sys_uid_max)
* [`sys_uid_min`](#-useradd--login_defs--sys_uid_min)
* [`syslog_sg_enab`](#-useradd--login_defs--syslog_sg_enab)
* [`syslog_su_enab`](#-useradd--login_defs--syslog_su_enab)
* [`ttygroup`](#-useradd--login_defs--ttygroup)
* [`ttyperm`](#-useradd--login_defs--ttyperm)
* [`ttytype_file`](#-useradd--login_defs--ttytype_file)
* [`uid_max`](#-useradd--login_defs--uid_max)
* [`uid_min`](#-useradd--login_defs--uid_min)
* [`umask`](#-useradd--login_defs--umask)
* [`ulimit`](#-useradd--login_defs--ulimit)
* [`userdel_cmd`](#-useradd--login_defs--userdel_cmd)
* [`usergroups_enab`](#-useradd--login_defs--usergroups_enab)

##### <a name="-useradd--login_defs--encrypt_method"></a>`encrypt_method`

Data type: `Enum['DES','MD5','SHA256','SHA512']`



Default value: `'SHA512'`

##### <a name="-useradd--login_defs--chfn_auth"></a>`chfn_auth`

Data type: `Boolean`



Default value: `false`

##### <a name="-useradd--login_defs--chfn_restrict"></a>`chfn_restrict`

Data type: `Pattern['^[frwh]+$']`



Default value: `'frwh'`

##### <a name="-useradd--login_defs--chsh_auth"></a>`chsh_auth`

Data type: `Boolean`



Default value: `false`

##### <a name="-useradd--login_defs--console"></a>`console`

Data type: `Optional[Array[Stdlib::AbsolutePath,1]]`



Default value: `undef`

##### <a name="-useradd--login_defs--console_groups"></a>`console_groups`

Data type: `Optional[Array[String,1]]`



Default value: `undef`

##### <a name="-useradd--login_defs--create_home"></a>`create_home`

Data type: `Boolean`



Default value: `true`

##### <a name="-useradd--login_defs--default_home"></a>`default_home`

Data type: `Boolean`



Default value: `false`

##### <a name="-useradd--login_defs--env_hz"></a>`env_hz`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-useradd--login_defs--env_path"></a>`env_path`

Data type: `Optional[Array[Stdlib::AbsolutePath,1]]`



Default value: `undef`

##### <a name="-useradd--login_defs--env_supath"></a>`env_supath`

Data type: `Optional[Array[Stdlib::AbsolutePath,1]]`



Default value: `undef`

##### <a name="-useradd--login_defs--env_tz"></a>`env_tz`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-useradd--login_defs--environ_file"></a>`environ_file`

Data type: `Optional[Stdlib::AbsolutePath]`



Default value: `undef`

##### <a name="-useradd--login_defs--erasechar"></a>`erasechar`

Data type: `Optional[Integer]`



Default value: `undef`

##### <a name="-useradd--login_defs--fail_delay"></a>`fail_delay`

Data type: `Integer`



Default value: `4`

##### <a name="-useradd--login_defs--faillog_enab"></a>`faillog_enab`

Data type: `Boolean`



Default value: `true`

##### <a name="-useradd--login_defs--fake_shell"></a>`fake_shell`

Data type: `Optional[Stdlib::AbsolutePath]`



Default value: `undef`

##### <a name="-useradd--login_defs--ftmp_file"></a>`ftmp_file`

Data type: `Optional[Stdlib::AbsolutePath]`



Default value: `undef`

##### <a name="-useradd--login_defs--gid_max"></a>`gid_max`

Data type: `Integer[1]`



Default value: `simplib::lookup('simp_options::gid::max', { 'default_value' => pick(fact('login_defs.gid_max'), 500000 ) })`

##### <a name="-useradd--login_defs--gid_min"></a>`gid_min`

Data type: `Integer[0]`



Default value: `simplib::lookup('simp_options::gid::min', { 'default_value' => pick(fact('login_defs.gid_min'), 1000 ) })`

##### <a name="-useradd--login_defs--hushlogin_file"></a>`hushlogin_file`

Data type: `Optional[Stdlib::AbsolutePath]`



Default value: `undef`

##### <a name="-useradd--login_defs--issue_file"></a>`issue_file`

Data type: `Stdlib::AbsolutePath`



Default value: `'/etc/issue'`

##### <a name="-useradd--login_defs--killchar"></a>`killchar`

Data type: `Optional[Integer]`



Default value: `undef`

##### <a name="-useradd--login_defs--lastlog_enab"></a>`lastlog_enab`

Data type: `Boolean`



Default value: `true`

##### <a name="-useradd--login_defs--login_string"></a>`login_string`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-useradd--login_defs--login_retries"></a>`login_retries`

Data type: `Integer`



Default value: `3`

##### <a name="-useradd--login_defs--login_timeout"></a>`login_timeout`

Data type: `Integer`



Default value: `60`

##### <a name="-useradd--login_defs--log_ok_logins"></a>`log_ok_logins`

Data type: `Boolean`



Default value: `true`

##### <a name="-useradd--login_defs--log_unkfail_enab"></a>`log_unkfail_enab`

Data type: `Boolean`



Default value: `true`

##### <a name="-useradd--login_defs--mail_check_enab"></a>`mail_check_enab`

Data type: `Boolean`



Default value: `true`

##### <a name="-useradd--login_defs--mail_dir"></a>`mail_dir`

Data type: `Stdlib::AbsolutePath`



Default value: `'/var/spool/mail'`

##### <a name="-useradd--login_defs--mail_file"></a>`mail_file`

Data type: `Optional[Stdlib::AbsolutePath]`



Default value: `undef`

##### <a name="-useradd--login_defs--max_members_per_group"></a>`max_members_per_group`

Data type: `Optional[Integer]`



Default value: `undef`

##### <a name="-useradd--login_defs--motd_file"></a>`motd_file`

Data type: `Optional[Array[Stdlib::AbsolutePath,1]]`



Default value: `undef`

##### <a name="-useradd--login_defs--nologins_file"></a>`nologins_file`

Data type: `Optional[Stdlib::AbsolutePath]`



Default value: `undef`

##### <a name="-useradd--login_defs--obscure_checks_enab"></a>`obscure_checks_enab`

Data type: `Boolean`



Default value: `true`

##### <a name="-useradd--login_defs--pass_always_warn"></a>`pass_always_warn`

Data type: `Boolean`



Default value: `true`

##### <a name="-useradd--login_defs--pass_change_tries"></a>`pass_change_tries`

Data type: `Integer`



Default value: `3`

##### <a name="-useradd--login_defs--pass_max_days"></a>`pass_max_days`

Data type: `Integer`



Default value: `180`

##### <a name="-useradd--login_defs--pass_min_days"></a>`pass_min_days`

Data type: `Integer`



Default value: `1`

##### <a name="-useradd--login_defs--pass_warn_age"></a>`pass_warn_age`

Data type: `Integer`



Default value: `14`

##### <a name="-useradd--login_defs--pass_max_len"></a>`pass_max_len`

Data type: `Optional[Integer]`



Default value: `undef`

##### <a name="-useradd--login_defs--pass_min_len"></a>`pass_min_len`

Data type: `Integer`



Default value: `15`

##### <a name="-useradd--login_defs--porttime_checks_enab"></a>`porttime_checks_enab`

Data type: `Boolean`



Default value: `true`

##### <a name="-useradd--login_defs--quotas_enab"></a>`quotas_enab`

Data type: `Boolean`



Default value: `true`

##### <a name="-useradd--login_defs--sha_crypt_min_rounds"></a>`sha_crypt_min_rounds`

Data type: `Integer`



Default value: `5000`

##### <a name="-useradd--login_defs--sha_crypt_max_rounds"></a>`sha_crypt_max_rounds`

Data type: `Integer`



Default value: `10000`

##### <a name="-useradd--login_defs--sulog_file"></a>`sulog_file`

Data type: `Optional[Stdlib::AbsolutePath]`



Default value: `undef`

##### <a name="-useradd--login_defs--su_name"></a>`su_name`

Data type: `String`



Default value: `'su'`

##### <a name="-useradd--login_defs--su_wheel_only"></a>`su_wheel_only`

Data type: `Boolean`



Default value: `false`

##### <a name="-useradd--login_defs--sys_gid_max"></a>`sys_gid_max`

Data type: `Optional[Integer]`



Default value: `undef`

##### <a name="-useradd--login_defs--sys_gid_min"></a>`sys_gid_min`

Data type: `Optional[Integer]`



Default value: `undef`

##### <a name="-useradd--login_defs--sys_uid_max"></a>`sys_uid_max`

Data type: `Optional[Integer]`



Default value: `undef`

##### <a name="-useradd--login_defs--sys_uid_min"></a>`sys_uid_min`

Data type: `Optional[Integer]`



Default value: `undef`

##### <a name="-useradd--login_defs--syslog_sg_enab"></a>`syslog_sg_enab`

Data type: `Boolean`



Default value: `true`

##### <a name="-useradd--login_defs--syslog_su_enab"></a>`syslog_su_enab`

Data type: `Boolean`



Default value: `true`

##### <a name="-useradd--login_defs--ttygroup"></a>`ttygroup`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-useradd--login_defs--ttyperm"></a>`ttyperm`

Data type: `Optional[Simplib::Umask]`



Default value: `undef`

##### <a name="-useradd--login_defs--ttytype_file"></a>`ttytype_file`

Data type: `Optional[Stdlib::AbsolutePath]`



Default value: `undef`

##### <a name="-useradd--login_defs--uid_max"></a>`uid_max`

Data type: `Integer[1]`



Default value: `simplib::lookup('simp_options::uid::max', { 'default_value' => pick(fact('login_defs.uid_max'), 1000000 ) })`

##### <a name="-useradd--login_defs--uid_min"></a>`uid_min`

Data type: `Integer[0]`



Default value: `simplib::lookup('simp_options::uid::min', { 'default_value' => pick(fact('login_defs.uid_min'), 1000 ) })`

##### <a name="-useradd--login_defs--umask"></a>`umask`

Data type: `String`



Default value: `'007'`

##### <a name="-useradd--login_defs--ulimit"></a>`ulimit`

Data type: `Optional[Integer]`



Default value: `undef`

##### <a name="-useradd--login_defs--userdel_cmd"></a>`userdel_cmd`

Data type: `Optional[Stdlib::AbsolutePath]`



Default value: `undef`

##### <a name="-useradd--login_defs--usergroups_enab"></a>`usergroups_enab`

Data type: `Boolean`



Default value: `true`

### <a name="useradd--nss"></a>`useradd::nss`

Install and configure the NSS configuration file.
See nss(5) for more details.

author: SIMP Team <simp@simp-project.com>

#### Parameters

The following parameters are available in the `useradd::nss` class:

* [`netid_authoritative`](#-useradd--nss--netid_authoritative)
* [`services_authoritative`](#-useradd--nss--services_authoritative)
* [`setent_batch_read`](#-useradd--nss--setent_batch_read)

##### <a name="-useradd--nss--netid_authoritative"></a>`netid_authoritative`

Data type: `Boolean`



Default value: `false`

##### <a name="-useradd--nss--services_authoritative"></a>`services_authoritative`

Data type: `Boolean`



Default value: `false`

##### <a name="-useradd--nss--setent_batch_read"></a>`setent_batch_read`

Data type: `Boolean`



Default value: `true`

### <a name="useradd--passwd"></a>`useradd::passwd`

Manage the permissions of shadow and passwd related files

author: SIMP Team <simp@simp-project.com>

### <a name="useradd--sysconfig_init"></a>`useradd::sysconfig_init`

Allow for the configuration of /etc/sysconfig/init

See /usr/share/doc/initscripts-<version>/sysconfig.txt for variable
  definitions.

For all `setcolor` variables, use the following color options as a string:
  * default
  * black
  * red
  * green
  * yellow
  * blue
  * magenta
  * cyan
  * white

author: SIMP Team <simp@simp-project.com>

#### Parameters

The following parameters are available in the `useradd::sysconfig_init` class:

* [`bootup`](#-useradd--sysconfig_init--bootup)
* [`res_col`](#-useradd--sysconfig_init--res_col)
* [`move_to_col`](#-useradd--sysconfig_init--move_to_col)
* [`setcolor_success`](#-useradd--sysconfig_init--setcolor_success)
* [`setcolor_failure`](#-useradd--sysconfig_init--setcolor_failure)
* [`setcolor_warning`](#-useradd--sysconfig_init--setcolor_warning)
* [`setcolor_normal`](#-useradd--sysconfig_init--setcolor_normal)
* [`single_user_login`](#-useradd--sysconfig_init--single_user_login)
* [`loglvl`](#-useradd--sysconfig_init--loglvl)
* [`prompt`](#-useradd--sysconfig_init--prompt)
* [`autoswap`](#-useradd--sysconfig_init--autoswap)

##### <a name="-useradd--sysconfig_init--bootup"></a>`bootup`

Data type: `Useradd::Bootup`



Default value: `'color'`

##### <a name="-useradd--sysconfig_init--res_col"></a>`res_col`

Data type: `Integer`



Default value: `60`

##### <a name="-useradd--sysconfig_init--move_to_col"></a>`move_to_col`

Data type: `Optional[String]`

* By default, undef will add the code `"echo -en \\033[${RES_COL}G"` to
  /etc/sysconfig/init
* Optional string of code will be substituted if included

Default value: `undef`

##### <a name="-useradd--sysconfig_init--setcolor_success"></a>`setcolor_success`

Data type: `String`



Default value: `'green'`

##### <a name="-useradd--sysconfig_init--setcolor_failure"></a>`setcolor_failure`

Data type: `String`



Default value: `'red'`

##### <a name="-useradd--sysconfig_init--setcolor_warning"></a>`setcolor_warning`

Data type: `String`



Default value: `'yellow'`

##### <a name="-useradd--sysconfig_init--setcolor_normal"></a>`setcolor_normal`

Data type: `String`



Default value: `'default'`

##### <a name="-useradd--sysconfig_init--single_user_login"></a>`single_user_login`

Data type: `Stdlib::AbsolutePath`



Default value: `'/sbin/sulogin'`

##### <a name="-useradd--sysconfig_init--loglvl"></a>`loglvl`

Data type: `Integer[1,8]`



Default value: `3`

##### <a name="-useradd--sysconfig_init--prompt"></a>`prompt`

Data type: `Boolean`



Default value: `false`

##### <a name="-useradd--sysconfig_init--autoswap"></a>`autoswap`

Data type: `Boolean`

AUTOSWAP option is only useful in el6.  Not present in el7 or later.

Default value: `false`

### <a name="useradd--useradd"></a>`useradd::useradd`

Install and configure the useradd default configuration file.
See useradd(8) for more details.

author: SIMP Team <simp@simp-project.com>

#### Parameters

The following parameters are available in the `useradd::useradd` class:

* [`group`](#-useradd--useradd--group)
* [`home`](#-useradd--useradd--home)
* [`inactive`](#-useradd--useradd--inactive)
* [`expire`](#-useradd--useradd--expire)
* [`shell`](#-useradd--useradd--shell)
* [`skel`](#-useradd--useradd--skel)
* [`create_mail_spool`](#-useradd--useradd--create_mail_spool)

##### <a name="-useradd--useradd--group"></a>`group`

Data type: `Integer`



Default value: `100`

##### <a name="-useradd--useradd--home"></a>`home`

Data type: `Stdlib::AbsolutePath`



Default value: `'/home'`

##### <a name="-useradd--useradd--inactive"></a>`inactive`

Data type: `Integer`



Default value: `35`

##### <a name="-useradd--useradd--expire"></a>`expire`

Data type:

```puppet
Optional[
    Pattern[/^\d{4}-\d{2}-\d{2}$/]
  ]
```



Default value: `undef`

##### <a name="-useradd--useradd--shell"></a>`shell`

Data type: `Stdlib::AbsolutePath`



Default value: `'/bin/bash'`

##### <a name="-useradd--useradd--skel"></a>`skel`

Data type: `Stdlib::AbsolutePath`



Default value: `'/etc/skel'`

##### <a name="-useradd--useradd--create_mail_spool"></a>`create_mail_spool`

Data type: `Boolean`



Default value: `true`

## Data types

### <a name="Useradd--Bootup"></a>`Useradd::Bootup`

Boot mode sysconfig option

Alias of `Enum['graphical', 'color', 'verbose', 'plain']`

### <a name="Useradd--CryptStyle"></a>`Useradd::CryptStyle`

The  algorithm to use for password encryption when creating new passwords

Alias of `Enum['BLOWFISH', 'DES', 'MD5', 'SHA256', 'SHA512', 'blowfish', 'des', 'md5', 'sha256', 'sha512']`

### <a name="Useradd--LibuserModule"></a>`Useradd::LibuserModule`

Valid libuser modules

Alias of `Enum['files', 'shadow', 'ldap']`

